@@ -15,8 +15,9 @@
 
 from logging import WARNING
 from unittest import TestCase
-from unittest.mock import Mock, patch
+from unittest.mock import MagicMock, Mock, patch
 
+from opentelemetry._metrics import NoOpMeter
 from opentelemetry.sdk._metrics import Meter, MeterProvider
 from opentelemetry.sdk._metrics.instrument import (
     Counter,
@@ -26,10 +27,24 @@ from opentelemetry.sdk._metrics.instrument import (
     ObservableUpDownCounter,
     UpDownCounter,
 )
+from opentelemetry.sdk._metrics.metric_reader import MetricReader
+from opentelemetry.sdk._metrics.point import AggregationTemporality
 from opentelemetry.sdk.resources import Resource
+from opentelemetry.test.concurrency_test import ConcurrencyTestBase, MockFunc
 
 
-class TestMeterProvider(TestCase):
+class DummyMetricReader(MetricReader):
+    def __init__(self):
+        super().__init__(AggregationTemporality.CUMULATIVE)
+
+    def _receive_metrics(self, metrics):
+        pass
+
+    def shutdown(self):
+        return True
+
+
+class TestMeterProvider(ConcurrencyTestBase):
     def test_resource(self):
         """
         `MeterProvider` provides a way to allow a `Resource` to be specified.
@@ -66,6 +81,28 @@ class TestMeterProvider(TestCase):
         self.assertEqual(meter._instrumentation_info.version, "version")
         self.assertEqual(meter._instrumentation_info.schema_url, "schema_url")
 
+    def test_get_meter_empty(self):
+        """
+        `MeterProvider.get_meter` called with None or empty string as name
+        should return a NoOpMeter.
+        """
+
+        meter = MeterProvider().get_meter(
+            None,
+            version="version",
+            schema_url="schema_url",
+        )
+        self.assertIsInstance(meter, NoOpMeter)
+        self.assertEqual(meter._name, None)
+
+        meter = MeterProvider().get_meter(
+            "",
+            version="version",
+            schema_url="schema_url",
+        )
+        self.assertIsInstance(meter, NoOpMeter)
+        self.assertEqual(meter._name, "")
+
     def test_get_meter_duplicate(self):
         """
         Subsequent calls to `MeterProvider.get_meter` with the same arguments
@@ -92,14 +129,24 @@ class TestMeterProvider(TestCase):
 
     def test_shutdown(self):
 
-        mock_metric_reader_0 = Mock(**{"shutdown.return_value": False})
+        mock_metric_reader_0 = MagicMock(
+            **{
+                "shutdown.return_value": False,
+                "__str__.return_value": "mock_metric_reader_0",
+            }
+        )
         mock_metric_reader_1 = Mock(**{"shutdown.return_value": True})
 
         meter_provider = MeterProvider(
             metric_readers=[mock_metric_reader_0, mock_metric_reader_1]
         )
 
-        self.assertFalse(meter_provider.shutdown())
+        with self.assertLogs(level=WARNING) as log:
+            self.assertFalse(meter_provider.shutdown())
+            self.assertEqual(
+                log.records[0].getMessage(),
+                "MetricReader mock_metric_reader_0 failed to shutdown",
+            )
         mock_metric_reader_0.shutdown.assert_called_once()
         mock_metric_reader_1.shutdown.assert_called_once()
 
@@ -129,6 +176,31 @@ class TestMeterProvider(TestCase):
         with self.assertLogs(level=WARNING):
             meter_provider.shutdown()
 
+    @patch("opentelemetry.sdk._metrics._logger")
+    def test_shutdown_race(self, mock_logger):
+        mock_logger.warning = MockFunc()
+        meter_provider = MeterProvider()
+        num_threads = 70
+        self.run_with_many_threads(
+            meter_provider.shutdown, num_threads=num_threads
+        )
+        self.assertEqual(mock_logger.warning.call_count, num_threads - 1)
+
+    @patch("opentelemetry.sdk._metrics.SynchronousMeasurementConsumer")
+    def test_measurement_collect_callback(
+        self, mock_sync_measurement_consumer
+    ):
+        metric_readers = [DummyMetricReader()] * 5
+        sync_consumer_instance = mock_sync_measurement_consumer()
+        sync_consumer_instance.collect = MockFunc()
+        MeterProvider(metric_readers=metric_readers)
+
+        for reader in metric_readers:
+            reader.collect()
+        self.assertEqual(
+            sync_consumer_instance.collect.call_count, len(metric_readers)
+        )
+
     @patch("opentelemetry.sdk._metrics.SynchronousMeasurementConsumer")
     def test_creates_sync_measurement_consumer(
         self, mock_sync_measurement_consumer
